queryengine

package
v0.0.0-...-db2c04b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 9, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GraviolaQueryEngine

type GraviolaQueryEngine struct {
	// contains filtered or unexported fields
}

This is a thin wrapper of Prometheus query engine, used to make it easier to debug and add telemetry. A query engine breaks the query into smaller pieces and send those pieces to the storage.

func NewGraviolaQueryEngine

func NewGraviolaQueryEngine(
	logger *slog.Logger, metricRegistry *prometheus.Registry, conf config.GraviolaConfig,
) *GraviolaQueryEngine

func (*GraviolaQueryEngine) NewInstantQuery

func (gravQueryEng *GraviolaQueryEngine) NewInstantQuery(
	ctx context.Context, queriable storage.Queryable, opts promql.QueryOpts, qs string, ts time.Time,
) (promql.Query, error)

QueryEngine

func (*GraviolaQueryEngine) NewRangeQuery

func (gravQueryEng *GraviolaQueryEngine) NewRangeQuery(
	ctx context.Context, queriable storage.Queryable, opts promql.QueryOpts, qs string, start, end time.Time,
	interval time.Duration,
) (promql.Query, error)

QueryEngine

func (*GraviolaQueryEngine) SetQueryLogger

func (gravQueryEng *GraviolaQueryEngine) SetQueryLogger(_ promql.QueryLogger)

QueryEngine

Jump to