Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GraviolaExemplarQueryable ¶
type GraviolaExemplarQueryable struct {
}
TODO: implement me
func (*GraviolaExemplarQueryable) ExemplarQuerier ¶
func (exQuerier *GraviolaExemplarQueryable) ExemplarQuerier(_ context.Context) (storage.ExemplarQuerier, error)
ExemplarQueryable nolint: nilnil
type GraviolaStorage ¶
type GraviolaStorage struct {
// contains filtered or unexported fields
}
GraviolaStorage is a wrapper around a list of groups. It implements the same interface of a Prometheus "Queryable". So, it acts like a "storage" of data
func NewGraviolaStorage ¶
func NewGraviolaStorage( logger *slog.Logger, groups []storage.Querier, mergeStrategy remotestoragegroup.MergeStrategy, ) *GraviolaStorage
func (*GraviolaStorage) ChunkQuerier ¶
func (gravStorage *GraviolaStorage) ChunkQuerier(_, _ int64) (storage.ChunkQuerier, error)
ChunkQueryable mint, maxt int64
Click to show internal directories.
Click to hide internal directories.